@@ -1,16 +1,18 @@
-#' Add padding to string
+#' MOVED Add padding to string
 #'
 #' @param d vector of strings or numbers
 #' @param length final string length
 #' @param after if padding should be added after as opposed to default before
 #' @param pad padding string of length 1
+#' @param lead leading string for all. Number or character vector. Cycled.
+#' @param tail tailing string for all. Number or character vector. Cycled.
 #'
 #' @return vector or character strings of same length.
 #' @export
 #'
 #' @examples
-#' add_padding(sample(1:200,5))
-add_padding <- function(d,length=NULL,after=FALSE,pad="0"){
+#' add_padding(sample(1:200,5),tail="AA",lead=c(2,3,"e"))
+add_padding <- function(d,length=NULL,after=FALSE,pad="0",lead=NULL,tail=NULL){
   if (!is.vector(d)) {
     stop("Please supply vector")
   }
@@ -31,8 +33,11 @@ add_padding <- function(d,length=NULL,after=FALSE,pad="0"){
     paste(rep(pad,i),collapse="")}))
   
   if (after) {
-    paste0(d,ps)
+    out <- paste0(d,ps)
   } else {
-    paste0(ps,d)
+    out <- paste0(ps,d)
   }
+  
+  paste0(lead,out,tail)
+
 }
